==> jc-1.4.0.tar.gz: javax/security/auth/callback/LanguageCallback.c <==
// public class javax.security.auth.callback.LanguageCallback

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class f2114aa4a5ab530b java_util_Locale
// @dep_class d07fd82a849e688e javax_security_auth_callback_Callback
// @dep_class 5d2a354b77c5048e javax_security_auth_callback_LanguageCallback

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Locale
// @dep_header javax_security_auth_callback_Callback
// @dep_header javax_security_auth_callback_LanguageCallback

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Locale.h"
#include "javax/security/auth/callback/Callback.h"
#include "javax/security/auth/callback/LanguageCallback.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.util.Locale locale
static _jc_field _jc_javax_security_auth_callback_LanguageCallback$field_info$locale = {
	.name=		"locale",
	.signature=	"Ljava/util/Locale;",
	.class=		&_jc_javax_security_auth_callback_LanguageCallback$type,
	.type=		&_jc_java_util_Locale$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_security_auth_callback_LanguageCallback$object, refs[-1].javax_security_auth_callback_LanguageCallback.locale),
};

// Fields
static _jc_field *const _jc_javax_security_auth_callback_LanguageCallback$fields[] = {
	&_jc_javax_security_auth_callback_LanguageCallback$field_info$locale
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_security_auth_callback_LanguageCallback$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_security_auth_callback_LanguageCallback$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_security_auth_callback_LanguageCallback$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_security_auth_callback_LanguageCallback$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_security_auth_callback_LanguageCallback$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_callback_LanguageCallback$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_callback_LanguageCallback, _init$52f4ad9f2989aeee);

void
_jc_javax_security_auth_callback_LanguageCallback$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_security_auth_callback_LanguageCallback$object *this)
{
	struct _jc_javax_security_auth_callback_LanguageCallback$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(70);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.util.Locale getLocale()
//

static _jc_linenum _jc_javax_security_auth_callback_LanguageCallback$linenum_table$getLocale$0f16f3de840c0c1e[];

static const unsigned char _jc_javax_security_auth_callback_LanguageCallback$param_ptypes$getLocale$0f16f3de840c0c1e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$getLocale$0f16f3de840c0c1e = {
	.name=			"getLocale",
	.signature=		"()Ljava/util/Locale;",
	.class=			&_jc_javax_security_auth_callback_LanguageCallback$type,
	.return_type=		&_jc_java_util_Locale$type,
	.param_ptypes=		&_jc_javax_security_auth_callback_LanguageCallback$param_ptypes$getLocale$0f16f3de840c0c1e,
	.signature_hash=	_JC_JLONG(0xf16f3de840c0c1e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_security_auth_callback_LanguageCallback$vtable, javax_security_auth_callback_LanguageCallback.getLocale$0f16f3de840c0c1e) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_callback_LanguageCallback$linenum_table$getLocale$0f16f3de840c0c1e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_callback_LanguageCallback, getLocale$0f16f3de840c0c1e);

_jc_java_util_Locale$object *
_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e(_jc_env *const env, _jc_javax_security_auth_callback_LanguageCallback$object *this)
{
	struct _jc_javax_security_auth_callback_LanguageCallback$object *r0;
	struct _jc_java_util_Locale$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(98);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_security_auth_callback_LanguageCallback, locale);
	return r1;
}

//
// public void setLocale(java.util.Locale)
//

static _jc_linenum _jc_javax_security_auth_callback_LanguageCallback$linenum_table$setLocale$6eaa1a56408d8bc9[];

static const unsigned char _jc_javax_security_auth_callback_LanguageCallback$param_ptypes$setLocale$6eaa1a56408d8bc9[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$param_types$setLocale$6eaa1a56408d8bc9[] = {
	&_jc_java_util_Locale$type
};

_jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$setLocale$6eaa1a56408d8bc9 = {
	.name=			"setLocale",
	.signature=		"(Ljava/util/Locale;)V",
	.class=			&_jc_javax_security_auth_callback_LanguageCallback$type,
	.param_types=		&_jc_javax_security_auth_callback_LanguageCallback$param_types$setLocale$6eaa1a56408d8bc9,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_security_auth_callback_LanguageCallback$param_ptypes$setLocale$6eaa1a56408d8bc9,
	.signature_hash=	_JC_JLONG(0x6eaa1a56408d8bc9),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_security_auth_callback_LanguageCallback$vtable, javax_security_auth_callback_LanguageCallback.setLocale$6eaa1a56408d8bc9) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_security_auth_callback_LanguageCallback$linenum_table$setLocale$6eaa1a56408d8bc9
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_callback_LanguageCallback, setLocale$6eaa1a56408d8bc9);

void
_jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9(_jc_env *const env, _jc_javax_security_auth_callback_LanguageCallback$object *this, _jc_java_util_Locale$object *param0)
{
	struct _jc_javax_security_auth_callback_LanguageCallback$object *r0;
	struct _jc_java_util_Locale$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(86);				// 0
	_JC_REF_FIELD(env, r0, javax_security_auth_callback_LanguageCallback, locale) = r1;
	_JC_LINE_NUMBER(87);				// 1
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_security_auth_callback_LanguageCallback$methods[] = {
	&_jc_javax_security_auth_callback_LanguageCallback$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_security_auth_callback_LanguageCallback$method_info$getLocale$0f16f3de840c0c1e,
	&_jc_javax_security_auth_callback_LanguageCallback$method_info$setLocale$6eaa1a56408d8bc9
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$interfaces[] = {
	&_jc_javax_security_auth_callback_Callback$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_14[] = {
	&_jc_javax_security_auth_callback_Callback$type,
	&_jc_javax_security_auth_callback_LanguageCallback$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[14]=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_14,
	[65]=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_65,
	[113]=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_security_auth_callback_LanguageCallback$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Locale",	_JC_JLONG(0xf2114aa4a5ab530b) },
	{ "javax/security/auth/callback/Callback",	_JC_JLONG(0xd07fd82a849e688e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_security_auth_callback_LanguageCallback$vtype _jc_javax_security_auth_callback_LanguageCallback$type = {
    .type= {
	.name=			"javax/security/auth/callback/LanguageCallback",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_security_auth_callback_LanguageCallback$interfaces) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$interfaces),
	.interfaces=		_jc_javax_security_auth_callback_LanguageCallback$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x5d2a354b77c5048e),
		.source_file=		"LanguageCallback.java",
		.instance_size=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$refs) + sizeof(_jc_javax_security_auth_callback_LanguageCallback$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$fields) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$fields),
		.fields=		_jc_javax_security_auth_callback_LanguageCallback$fields,
		.num_methods=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$methods) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$methods),
		.methods=		_jc_javax_security_auth_callback_LanguageCallback$methods,
		.instanceof_hash_table=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$class_depends) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$class_depends),
		.class_depends=		_jc_javax_security_auth_callback_LanguageCallback$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_security_auth_callback_LanguageCallback= {
	    .getLocale$0f16f3de840c0c1e=
		&_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e,
	    .setLocale$6eaa1a56408d8bc9=
		&_jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/security/auth/callback/LanguageCallback.c <==
// public class javax.security.auth.callback.LanguageCallback

// class file dependencies
// @dep_class 9a35c7173b37e641 java_io_Serializable
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class f2114aa4a5ab530b java_util_Locale
// @dep_class d07fd82a849e688e javax_security_auth_callback_Callback
// @dep_class 5d2a354b77c5048e javax_security_auth_callback_LanguageCallback

// header file dependencies
// @dep_header java_io_Serializable
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Locale
// @dep_header javax_security_auth_callback_Callback
// @dep_header javax_security_auth_callback_LanguageCallback

#include "jc_defs.h"

#include "java/io/Serializable.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Locale.h"
#include "javax/security/auth/callback/Callback.h"
#include "javax/security/auth/callback/LanguageCallback.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.util.Locale locale
static _jc_field _jc_javax_security_auth_callback_LanguageCallback$field_info$locale = {
	.name=		"locale",
	.signature=	"Ljava/util/Locale;",
	.class=		&_jc_javax_security_auth_callback_LanguageCallback$type,
	.type=		&_jc_java_util_Locale$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_security_auth_callback_LanguageCallback$object, refs[-1].javax_security_auth_callback_LanguageCallback.locale),
};

// Fields
static _jc_field *const _jc_javax_security_auth_callback_LanguageCallback$fields[] = {
	&_jc_javax_security_auth_callback_LanguageCallback$field_info$locale
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_javax_security_auth_callback_LanguageCallback$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_javax_security_auth_callback_LanguageCallback$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_javax_security_auth_callback_LanguageCallback$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_security_auth_callback_LanguageCallback$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_security_auth_callback_LanguageCallback$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_callback_LanguageCallback$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_callback_LanguageCallback, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_javax_security_auth_callback_LanguageCallback$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_javax_security_auth_callback_LanguageCallback$object *this)
{
	struct _jc_javax_security_auth_callback_LanguageCallback$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(70);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.util.Locale getLocale()
//

static _jc_linenum _jc_javax_security_auth_callback_LanguageCallback$linenum_table$getLocale$0f16f3de840c0c1e[];

static const unsigned char _jc_javax_security_auth_callback_LanguageCallback$param_ptypes$getLocale$0f16f3de840c0c1e[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$getLocale$0f16f3de840c0c1e = {
	.name=			"getLocale",
	.signature=		"()Ljava/util/Locale;",
	.class=			&_jc_javax_security_auth_callback_LanguageCallback$type,
	.return_type=		&_jc_java_util_Locale$type,
	.param_ptypes=		&_jc_javax_security_auth_callback_LanguageCallback$param_ptypes$getLocale$0f16f3de840c0c1e,
	.signature_hash=	_JC_JLONG(0xf16f3de840c0c1e),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_security_auth_callback_LanguageCallback$vtable, javax_security_auth_callback_LanguageCallback.getLocale$0f16f3de840c0c1e) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_security_auth_callback_LanguageCallback$linenum_table$getLocale$0f16f3de840c0c1e
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_callback_LanguageCallback, getLocale$0f16f3de840c0c1e);

_jc_java_util_Locale$object * _JC_JCNI_ATTR
_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e(_jc_env *const env, _jc_javax_security_auth_callback_LanguageCallback$object *this)
{
	struct _jc_javax_security_auth_callback_LanguageCallback$object *r0;
	struct _jc_java_util_Locale$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(98);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_security_auth_callback_LanguageCallback, locale);
	return r1;
}

//
// public void setLocale(java.util.Locale)
//

static _jc_linenum _jc_javax_security_auth_callback_LanguageCallback$linenum_table$setLocale$6eaa1a56408d8bc9[];

static const unsigned char _jc_javax_security_auth_callback_LanguageCallback$param_ptypes$setLocale$6eaa1a56408d8bc9[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$param_types$setLocale$6eaa1a56408d8bc9[] = {
	&_jc_java_util_Locale$type
};

_jc_method _jc_javax_security_auth_callback_LanguageCallback$method_info$setLocale$6eaa1a56408d8bc9 = {
	.name=			"setLocale",
	.signature=		"(Ljava/util/Locale;)V",
	.class=			&_jc_javax_security_auth_callback_LanguageCallback$type,
	.param_types=		&_jc_javax_security_auth_callback_LanguageCallback$param_types$setLocale$6eaa1a56408d8bc9,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_security_auth_callback_LanguageCallback$param_ptypes$setLocale$6eaa1a56408d8bc9,
	.signature_hash=	_JC_JLONG(0x6eaa1a56408d8bc9),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_security_auth_callback_LanguageCallback$vtable, javax_security_auth_callback_LanguageCallback.setLocale$6eaa1a56408d8bc9) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_javax_security_auth_callback_LanguageCallback$linenum_table$setLocale$6eaa1a56408d8bc9
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_security_auth_callback_LanguageCallback, setLocale$6eaa1a56408d8bc9);

void _JC_JCNI_ATTR
_jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9(_jc_env *const env, _jc_javax_security_auth_callback_LanguageCallback$object *this, _jc_java_util_Locale$object *param0)
{
	struct _jc_javax_security_auth_callback_LanguageCallback$object *r0;
	struct _jc_java_util_Locale$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(86);				// 0
	_JC_REF_FIELD(env, r0, javax_security_auth_callback_LanguageCallback, locale) = r1;
	_JC_LINE_NUMBER(87);				// 1
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_security_auth_callback_LanguageCallback$methods[] = {
	&_jc_javax_security_auth_callback_LanguageCallback$method_info$_init$52f4ad9f2989aeee,
	&_jc_javax_security_auth_callback_LanguageCallback$method_info$getLocale$0f16f3de840c0c1e,
	&_jc_javax_security_auth_callback_LanguageCallback$method_info$setLocale$6eaa1a56408d8bc9
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$interfaces[] = {
	&_jc_javax_security_auth_callback_Callback$type,
	&_jc_java_io_Serializable$type
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_14[] = {
	&_jc_javax_security_auth_callback_Callback$type,
	&_jc_javax_security_auth_callback_LanguageCallback$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_65[] = {
	&_jc_java_io_Serializable$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[14]=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_14,
	[65]=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_65,
	[101]=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_security_auth_callback_LanguageCallback$class_depends[] = {
	{ "java/io/Serializable",	_JC_JLONG(0x9a35c7173b37e641) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Locale",	_JC_JLONG(0xf2114aa4a5ab530b) },
	{ "javax/security/auth/callback/Callback",	_JC_JLONG(0xd07fd82a849e688e) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_security_auth_callback_LanguageCallback$vtype _jc_javax_security_auth_callback_LanguageCallback$type = {
    .type= {
	.name=			"javax/security/auth/callback/LanguageCallback",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_javax_security_auth_callback_LanguageCallback$interfaces) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$interfaces),
	.interfaces=		_jc_javax_security_auth_callback_LanguageCallback$interfaces,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x5d2a354b77c5048e),
		.source_file=		"LanguageCallback.java",
		.instance_size=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$refs) + sizeof(_jc_javax_security_auth_callback_LanguageCallback$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$fields) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$fields),
		.fields=		_jc_javax_security_auth_callback_LanguageCallback$fields,
		.num_methods=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$methods) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$methods),
		.methods=		_jc_javax_security_auth_callback_LanguageCallback$methods,
		.instanceof_hash_table=	_jc_javax_security_auth_callback_LanguageCallback$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_javax_security_auth_callback_LanguageCallback$class_depends) / sizeof(*_jc_javax_security_auth_callback_LanguageCallback$class_depends),
		.class_depends=		_jc_javax_security_auth_callback_LanguageCallback$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_security_auth_callback_LanguageCallback= {
	    .getLocale$0f16f3de840c0c1e=
		&_jc_javax_security_auth_callback_LanguageCallback$method$getLocale$0f16f3de840c0c1e,
	    .setLocale$6eaa1a56408d8bc9=
		&_jc_javax_security_auth_callback_LanguageCallback$method$setLocale$6eaa1a56408d8bc9,
	},
    }
};
